==> supplier-center-api-1.2.6-20231031.090034-1-sources.jar: cn/com/duiba/supplier/center/api/request/order/QueryDuiBaSupplyOrdersPageRequest.java <==
package cn.com.duiba.supplier.center.api.request.order;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class QueryDuiBaSupplyOrdersPageRequest implements Serializable {

    private static final long serialVersionUID = -1404927514138850792L;

    /** 下单时间开始 */
    private Date startTime;
    /** 下单时间结束 */
    private Date endTime;
    /** 订单状态 */
    private Integer orderStatus;
    /** 来源app名称 */
    private String appName;
    /** 分页大小 */
    private Integer pageSize;
    /** 分页页码 */
    private Integer pageNo;

    /** 查询用 数据偏移量 */
    private Integer offset;
    /** 订单类型 实物 卡密 优惠券 */
    private String itemType;

    private List<Long> appItemIds;

    //通过developerId
    private List<String> appNames;

    private String itemName;
    /**
     * 手机号
     */
    private String phone;

    /**
     * 最大的ID：用于导出时的深分页处理
     */
    private Long maxId;

    /**
     * 充值账号
     */
    private String rechargeAccount;

    private Long appId;

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getRechargeAccount() {
        return rechargeAccount;
    }

    public void setRechargeAccount(String rechargeAccount) {
        this.rechargeAccount = rechargeAccount;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public List<String> getAppNames() {
        return appNames;
    }

    public void setAppNames(List<String> appNames) {
        this.appNames = appNames;
    }

    public List<Long> getAppItemIds() {
        return appItemIds;
    }

    public void setAppItemIds(List<Long> appItemIds) {
        this.appItemIds = appItemIds;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(Integer orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }
}

==> supplier-center-api-2.1.55-20251107.093928-1-sources.jar: cn/com/duiba/supplier/center/api/request/order/QueryDuiBaSupplyOrdersPageRequest.java <==
package cn.com.duiba.supplier.center.api.request.order;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class QueryDuiBaSupplyOrdersPageRequest implements Serializable {

    private static final long serialVersionUID = -1404927514138850792L;

    /** 下单时间开始 */
    private Date startTime;
    /** 下单时间结束 */
    private Date endTime;
    /** 订单状态 */
    private Integer orderStatus;
    /** 来源app名称 */
    private String appName;
    /** 分页大小 */
    private Integer pageSize;
    /** 分页页码 */
    private Integer pageNo;

    /** 查询用 数据偏移量 */
    private Integer offset;
    /** 订单类型 实物 卡密 优惠券 */
    private String itemType;

    private List<Long> appItemIds;

    //通过developerId
    private List<String> appNames;

    private String itemName;
    /**
     * 手机号
     */
    private String phone;

    /**
     * 最大的ID：用于导出时的深分页处理
     */
    private Long maxId;

    /**
     * 充值账号
     */
    private String rechargeAccount;

    private Long appId;

    private List<Long> appIds;

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getMaxId() {
        return maxId;
    }

    public void setMaxId(Long maxId) {
        this.maxId = maxId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getRechargeAccount() {
        return rechargeAccount;
    }

    public void setRechargeAccount(String rechargeAccount) {
        this.rechargeAccount = rechargeAccount;
    }

    public String getItemName() {
        return itemName;
    }

    public void setItemName(String itemName) {
        this.itemName = itemName;
    }

    public List<String> getAppNames() {
        return appNames;
    }

    public void setAppNames(List<String> appNames) {
        this.appNames = appNames;
    }

    public List<Long> getAppItemIds() {
        return appItemIds;
    }

    public void setAppItemIds(List<Long> appItemIds) {
        this.appItemIds = appItemIds;
    }

    public String getItemType() {
        return itemType;
    }

    public void setItemType(String itemType) {
        this.itemType = itemType;
    }
    public Date getStartTime() {
        return startTime;
    }

    public void setStartTime(Date startTime) {
        this.startTime = startTime;
    }

    public Date getEndTime() {
        return endTime;
    }

    public void setEndTime(Date endTime) {
        this.endTime = endTime;
    }

    public Integer getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(Integer orderStatus) {
        this.orderStatus = orderStatus;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getPageNo() {
        return pageNo;
    }

    public void setPageNo(Integer pageNo) {
        this.pageNo = pageNo;
    }

    public Integer getOffset() {
        return offset;
    }

    public void setOffset(Integer offset) {
        this.offset = offset;
    }
}
